/*
 :******************************************************************
 :* MODULE-DESCRIPTION
 :*
 :* TITLE         (/ library predefined procedures and functions   /)
 :*
 :* NAME          regular.c
 :*
 :* COPYRIGHT     (C)   SIEMENS NIXDORF INFORMATIONSSYSTEME AG  1992
 :*                     ALL RIGHTS RESERVED
 :*
 :* MEMORY-CLASS  6
 :*
 :* PROG-CONVENTS (/ <internal conventions (instance, names,
 :*                  external data, ...). None -> empty text>     /)
 :*
 :* PROCEDURE     match
 :* REMARKS       (/ matching a regular expression with a string  /)
 :* ENTRY         EXTERNAL
 :*
 :*-----------------------------------------------------------------
 :*
 :* VERSION       001
 :*   CRDATE      1992-12-02
 :*   AUTHOR      (/ Mounji Abdelaziz    , FUNDP /)
 :*   UPDATE      (/ original issue /)
 :*
 :* END-MODULE-DESCRIPTION regular.c
 :******************************************************************
*/
#include "asax.h"		/* definition of al external data and types */

/*
 :******************************************************************
 :* UNIT-BODY regular.match
 :*
 :* TITLE         (/ matching a regular expression with a string    /)
 :*
 :* PURPOSE       (/ compile the given regular expression and match it with 
 :*	  	     the second argument. Return 1 if match occurrs or 0 
 :*		     if no match.            /)
 :*                                                      END-PURPOSE
 :* VERSION       001
 :*   CRDATE      1992-12-02
 :*   AUTHOR      (/ Mounji Abdelaziz       , FUNDP              /)
 :*   UPDATE      (/ original issue /)
 :*
 :* REALIZATION   (/ <note, reference to other proc. (optional)> /)
 :*
 :*   CONTROL    (/
 :*
 :*                                                               /)
 :*   DATA       (/
 :*         GLOBAL DATA:
 :*                     - sp: current position in the regular exprerssion
 :* 			      buffer;
 :*                                                               /)
 :*
 :*                                                          END-DATA
 :*   ASSUMPTIONS     (/ <external conditions> /)
 :*   PERFORMANCE     (/ <measures taken or not: when, why, how> /)
 :*   VALIDATION      (/ <for which param. or other data ? How ?> /)
 :*   SYNCHRONIZATION (/ <serialization & locks: purpose, method> /)
 :*   INIT&TERM       (/ <what must already/still be available> /)
 :*   ERROR-HANDLING  (/ <reaction to errors, r.c., state of data>/)
 :*   DOCUMENTS       (/
 :*                                Preliminary report on
 :*                      Advanced Security Audit trail Analysis on uniX
 :*                             (ASAX also called SAT-X)
 :*
 :*                      Advanced Security Audit trail analysis on uniX
 :*                             (ASAX also called SAT-X)
 :*                      Implementation design of the NADF Evaluator   
 :* 			
 :*			Refer to Regular Expressions Syntax as supported by the
 :* 			the following Unix commands:
 :* 				- ed 
 :* 				- expr
 :* 				- grep 
 :* 				- more
 :* 				- page
 :* 				- sed 
 :* 			Note that the Unix commands
 :* 				- awk 
 :* 				- egrep  			
 :*			use an extended form of RE which is a superset of the
 :*			REs that are supported by match.                  /) 
 :*                                                  		END-REALIZATION
 :* PARAMETERS
 :*
 :*   Pre    (/ - 'm' points to an area containing two pointers of 4 bytes each;
 :*	        -  the first points to the RE; 
 :*		-  the second points to the string to be matched with the RE; 
 :*		-  this is depicted in the following figure:
 :*
 :*			'm'
 :*			   |
 :*			  \|/
 :*                         _______
 :*                        |_|_|_|_|
 :*                          |   |______________
 :*                         \|/		       \|/
 :*                          |l1|RegExpr |      |l2|String  | 
 :*                           -----------	 -----------
 :*
 :*             - l1 is the length of RegExpr;
 :*             - l2 is the length of String;
 :*                                                                     /)
 :*                                                             END-Pre
 :*   Post   (/ - if the string String matches the regular expression RegExpr
 :* 		  1 is returned; otherwise, 0 is returned.
 :* 		- Any syntactic error in the RE RegExpr is reported;
 :* 		- if l1>BUFSIZE or l2 > ESIZE an error is reported;
 :*                                                                 /)
 :*
 :*                                                             END-Post
 :*   RETURNS  "int"      (/ No match if = 0, match if =1; /)
 :*
 :*   REMARKS             (/ <general notes (none -> no REMARKS)> /)
 :*                                                   END-PARAMETERS
 :*
 :* END-BODY regular.match
 :******************************************************************
*/
void *match(m)
char *m;
{
char *expbuf;		/* receives the compiled  RE */
char *getExtStrRepr();  /* converts an ASAX string (lg, value) to the null */ 
			/* terminated form   */
char *str;		/* null terminated string repr. of String */
hole **sp1, **sp2;	/* auxiliary pointers */

  sp1 = (hole **) m++;
  expbuf = getExtStrRepr(*sp1);  /* the regular expression */
  sp1++; 
  str    = getExtStrRepr(*sp1);  /* the string to be matched with thw RE. */
  if (step(str, expbuf)) 
     return ((void *) 1);
  return ((void *) 0);
}
